@@ -4,7 +4,7 @@ import warnings
 from contextlib import contextmanager
 from datetime import datetime
 from functools import wraps
-from typing import Any, Callable, Dict, List, Sequence, Union
+from typing import Any, Callable, Dict, List, Optional, Sequence, Union
 from urllib.parse import urlparse
 
 import requests
@@ -27,7 +27,10 @@ class NetsuiteResponseError(Exception):
 
 
 def WebServiceCall(
-    path: str = None, extract: Callable = None, *, default: Any = constants.NOT_SET,
+    path: str = None,
+    extract: Callable = None,
+    *,
+    default: Any = constants.NOT_SET,
 ) -> Callable:
     """
     Decorator for NetSuite methods returning SOAP responses
@@ -138,7 +141,7 @@ class NetSuite:
 
     def __init__(
         self,
-        config: Union[Config, Dict],
+        config: Union[Config, Dict[str, Any]],
         *,
         version: str = None,
         wsdl_url: str = None,
@@ -213,7 +216,7 @@ class NetSuite:
     def service(self) -> zeep.client.ServiceProxy:
         return self.client.service
 
-    def _make_config(self, values_obj: Dict) -> Config:
+    def _make_config(self, values_obj: Union[Config, Dict[str, Any]]) -> Config:
         if isinstance(values_obj, Config):
             return values_obj
         return Config(**values_obj)
@@ -230,7 +233,7 @@ class NetSuite:
         return self.wsdl_url_tmpl.format(
             underscored_version=self.underscored_version,
             # https://followingnetsuite.wordpress.com/2018/10/18/suitetalk-sandbox-urls-addendum/
-            account_id=self.config.account.lower().replace("_", "-"),
+            account_id=(self.config.account or "").lower().replace("_", "-"),
         )
 
     def _generate_cache(self) -> zeep.cache.Base:
@@ -241,7 +244,9 @@ class NetSuite:
 
     def _generate_transport(self) -> zeep.transports.Transport:
         return NetSuiteTransport(
-            self._generate_wsdl_url(), session=self.session, cache=self.cache,
+            self._generate_wsdl_url(),
+            session=self.session,
+            cache=self.cache,
         )
 
     def generate_passport(self) -> Dict:
@@ -274,9 +279,13 @@ class NetSuite:
         )
 
     def _generate_client(self) -> zeep.Client:
-        client = zeep.Client(self.wsdl_url, transport=self.transport,)
+        client = zeep.Client(
+            self.wsdl_url,
+            transport=self.transport,
+        )
         self._set_default_soapheaders(
-            client, preferences=self.config.preferences,
+            client,
+            preferences=self.config.preferences,
         )
         return client
 
@@ -474,7 +483,7 @@ class NetSuite:
     def SupplyChainTypes(self) -> zeep.client.Factory:
         return self._type_factory("types.supplychain", "lists")
 
-    def request(self, service_name: str, *args, **kw) -> zeep.xsd.ComplexType:
+    def request(self, service_name: str, *args, **kw):
         """
         Make a web service request to NetSuite
 
@@ -495,30 +504,45 @@ class NetSuite:
         self,
         recordType: str,
         *,
-        internalIds: Sequence[int] = (),
-        externalIds: Sequence[str] = (),
+        internalIds: Optional[Sequence[int]] = None,
+        externalIds: Optional[Sequence[str]] = None,
     ) -> List[CompoundValue]:
         """Get a list of records"""
+        if internalIds is None:
+            internalIds = []
+        else:
+            internalIds = list(internalIds)
+        if externalIds is None:
+            externalIds = []
+        else:
+            externalIds = list(externalIds)
 
-        if len(list(internalIds) + list(externalIds)) == 0:
-            raise ValueError("Please specify `internalId` and/or `externalId`")
+        if len(internalIds) + len(externalIds) == 0:
+            return []
 
         return self.request(
             "getList",
             self.Messages.GetListRequest(
                 baseRef=[
-                    self.Core.RecordRef(type=recordType, internalId=internalId,)
+                    self.Core.RecordRef(
+                        type=recordType,
+                        internalId=internalId,
+                    )
                     for internalId in internalIds
                 ]
                 + [
-                    self.Core.RecordRef(type=recordType, externalId=externalId,)
+                    self.Core.RecordRef(
+                        type=recordType,
+                        externalId=externalId,
+                    )
                     for externalId in externalIds
                 ],
             ),
         )
 
     @WebServiceCall(
-        "body.readResponse", extract=lambda resp: resp["record"],
+        "body.readResponse",
+        extract=lambda resp: resp["record"],
     )
     def get(
         self, recordType: str, *, internalId: int = None, externalId: str = None
@@ -528,46 +552,58 @@ class NetSuite:
             raise ValueError("Specify either `internalId` or `externalId`")
 
         if internalId:
-            record_ref = self.Core.RecordRef(type=recordType, internalId=internalId,)
+            record_ref = self.Core.RecordRef(
+                type=recordType,
+                internalId=internalId,
+            )
         else:
-            self.Core.RecordRef(
-                type=recordType, externalId=externalId,
+            record_ref = self.Core.RecordRef(
+                type=recordType,
+                externalId=externalId,
             )
 
         return self.request("get", baseRef=record_ref)
 
     @WebServiceCall(
-        "body.getAllResult", extract=lambda resp: resp["recordList"]["record"],
+        "body.getAllResult",
+        extract=lambda resp: resp["recordList"]["record"],
     )
     def getAll(self, recordType: str) -> List[CompoundValue]:
         """Get all records of a given type."""
         return self.request(
-            "getAll", record=self.Core.GetAllRecord(recordType=recordType,),
+            "getAll",
+            record=self.Core.GetAllRecord(
+                recordType=recordType,
+            ),
         )
 
     @WebServiceCall(
-        "body.writeResponse", extract=lambda resp: resp["baseRef"],
+        "body.writeResponse",
+        extract=lambda resp: resp["baseRef"],
     )
     def add(self, record: CompoundValue) -> CompoundValue:
         """Insert a single record."""
         return self.request("add", record=record)
 
     @WebServiceCall(
-        "body.writeResponse", extract=lambda resp: resp["baseRef"],
+        "body.writeResponse",
+        extract=lambda resp: resp["baseRef"],
     )
     def update(self, record: CompoundValue) -> CompoundValue:
         """Insert a single record."""
         return self.request("update", record=record)
 
     @WebServiceCall(
-        "body.writeResponse", extract=lambda resp: resp["baseRef"],
+        "body.writeResponse",
+        extract=lambda resp: resp["baseRef"],
     )
     def upsert(self, record: CompoundValue) -> CompoundValue:
         """Upsert a single record."""
         return self.request("upsert", record=record)
 
     @WebServiceCall(
-        "body.searchResult", extract=lambda resp: resp["recordList"]["record"],
+        "body.searchResult",
+        extract=lambda resp: resp["recordList"]["record"],
     )
     def search(self, record: CompoundValue) -> List[CompoundValue]:
         """Search records"""
@@ -589,12 +625,21 @@ class NetSuite:
     def getItemAvailability(
         self,
         *,
-        internalIds: Sequence[int] = (),
-        externalIds: Sequence[str] = (),
+        internalIds: Optional[Sequence[int]] = None,
+        externalIds: Optional[Sequence[str]] = None,
         lastQtyAvailableChange: datetime = None,
     ) -> List[Dict]:
-        if len(list(internalIds) + list(externalIds)) == 0:
-            raise ValueError("Please specify `internalId` and/or `externalId`")
+        if internalIds is None:
+            internalIds = []
+        else:
+            internalIds = list(internalIds)
+        if externalIds is None:
+            externalIds = []
+        else:
+            externalIds = list(externalIds)
+
+        if len(internalIds) + len(externalIds) == 0:
+            return []
 
         item_filters = [
             {"type": "inventoryItem", "internalId": internalId}
