@@ -1,16 +1,16 @@
 import asyncio
 import logging
-from typing import Iterable, Optional
+from typing import Sequence
 
 from . import json
-from .types import JsonDict
+from .util import cached_property
 
 try:
     import httpx
 except ImportError:
 
-    class httpx:
-        Response = None  # NOTE: For type hint to work
+    class httpx:  # type: ignore[no-redef]
+        Response = None
 
 
 try:
@@ -48,7 +48,7 @@ class NetSuiteRestApi:
         consumer_secret: str,
         token_id: str,
         token_secret: str,
-        default_timeout: str = 60,
+        default_timeout: int = 60,
         concurrent_requests: int = 10,
     ):
         if not self.has_required_dependencies():
@@ -57,22 +57,33 @@ class NetSuiteRestApi:
                 "Install with `pip install netsuite[rest_api]`"
             )
         self._account = account
+        self._consumer_key = consumer_key
+        self._consumer_secret = consumer_secret
+        self._token_id = token_id
+        self._token_secret = token_secret
         self._hostname = self._make_hostname()
-        self._auth = self._make_auth(
-            account, consumer_key, consumer_secret, token_id, token_secret
-        )
         self._default_timeout = default_timeout
-        self._request_semaphore = asyncio.Semaphore(concurrent_requests)
+        self._concurrent_requests = concurrent_requests
+
+    @cached_property
+    def request_semaphore(self) -> asyncio.Semaphore:
+        # NOTE: Shouldn't be put in __init__ as we might not have a running
+        #       event loop at that time.
+        return asyncio.Semaphore(self._concurrent_requests)
 
     @classmethod
     def has_required_dependencies(cls) -> bool:
         return httpx is not None and OAuth1Auth is not None
 
-    async def get(self, subpath: str, **request_kw) -> JsonDict:
+    async def get(self, subpath: str, **request_kw):
         return await self.request("GET", subpath, **request_kw)
 
     async def post(self, subpath: str, **request_kw):
-        return await self.request("POST", subpath, **request_kw,)
+        return await self.request(
+            "POST",
+            subpath,
+            **request_kw,
+        )
 
     async def put(self, subpath: str, **request_kw):
         return await self.request("PUT", subpath, **request_kw)
@@ -83,7 +94,7 @@ class NetSuiteRestApi:
     async def delete(self, subpath: str, **request_kw):
         return await self.request("DELETE", subpath, **request_kw)
 
-    async def suiteql(self, q: str, limit: int = 10, offset: int = 0) -> JsonDict:
+    async def suiteql(self, q: str, limit: int = 10, offset: int = 0):
         return await self.request(
             "POST",
             "/query/v1/suiteql",
@@ -92,7 +103,7 @@ class NetSuiteRestApi:
             params={"limit": limit, "offset": offset},
         )
 
-    async def jsonschema(self, record_type: str, **request_kw) -> JsonDict:
+    async def jsonschema(self, record_type: str, **request_kw):
         headers = {
             **request_kw.pop("headers", {}),
             "Accept": "application/schema+json",
@@ -104,7 +115,7 @@ class NetSuiteRestApi:
             **request_kw,
         )
 
-    async def openapi(self, record_types: Iterable[str] = (), **request_kw) -> JsonDict:
+    async def openapi(self, record_types: Sequence[str] = (), **request_kw):
         headers = {
             **request_kw.pop("headers", {}),
             "Accept": "application/swagger+json",
@@ -122,9 +133,7 @@ class NetSuiteRestApi:
             **request_kw,
         )
 
-    async def request(
-        self, method: str, subpath: str, **request_kw
-    ) -> Optional[JsonDict]:
+    async def request(self, method: str, subpath: str, **request_kw):
         resp = await self._raw_request(method, subpath, **request_kw)
 
         if resp.status_code < 200 or resp.status_code > 299:
@@ -145,7 +154,6 @@ class NetSuiteRestApi:
         url = self._make_url(subpath)
         headers = {**self._make_default_headers(), **request_kw.pop("headers", {})}
 
-        auth = request_kw.pop("auth", self._auth)
         timeout = request_kw.pop("timeout", self._default_timeout)
 
         if "json" in request_kw:
@@ -156,13 +164,13 @@ class NetSuiteRestApi:
             f"Making {method.upper()} request to {url}. Keyword arguments: {kw}"
         )
 
-        async with self._request_semaphore:
+        async with self.request_semaphore:
             async with httpx.AsyncClient() as c:
                 resp = await c.request(
                     method=method,
                     url=url,
                     headers=headers,
-                    auth=auth,
+                    auth=self._make_auth(),
                     timeout=timeout,
                     **kw,
                 )
@@ -181,20 +189,14 @@ class NetSuiteRestApi:
     def _make_url(self, subpath: str):
         return f"https://{self._hostname}/services/rest{subpath}"
 
-    @staticmethod
-    def _make_auth(
-        account: str,
-        consumer_key: str,
-        consumer_secret: str,
-        token_id: str,
-        token_secret: str,
-    ):
+    def _make_auth(self):
         return OAuth1Auth(
-            client_id=consumer_key,
-            client_secret=consumer_secret,
-            token=token_id,
-            token_secret=token_secret,
-            realm=account,
+            client_id=self._consumer_key,
+            client_secret=self._consumer_secret,
+            token=self._token_id,
+            token_secret=self._token_secret,
+            realm=self._account,
+            force_include_body=True,
         )
 
     def _make_default_headers(self):
